@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021 -- leonerd@leonerd.org.uk
 
-package Syntax::Operator::Equ 0.01;
+package Syntax::Operator::Equ 0.02;
 
 use v5.14;
 use warnings;
@@ -84,6 +84,11 @@ sub import_into
    my %syms = map { $_ => 1 } @syms;
    $^H{"Syntax::Operator::Equ/equ"}++ if delete $syms{equ};
 
+   foreach (qw( is_strequ is_numequ )) {
+      no strict 'refs';
+      *{"${caller}::$_"} = \&{$_} if delete $syms{$_};
+   }
+
    croak "Unrecognised import symbols @{[ keys %syms ]}" if keys %syms;
 }
 
@@ -111,6 +116,33 @@ as numbers.
 
 =cut
 
+=head1 FUNCTIONS
+
+As a convenience, the following functions may be imported which implement the
+same behaviour as the infix operators, though are accessed via regular
+function call syntax.
+
+These wrapper functions are implemented using L<XS::Parse::Infix>, and thus
+have an optimising call-checker attached to them. In most cases, code which
+calls them should not in fact have the full runtime overhead of a function
+call because the underlying test operator will get inlined into the calling
+code at compiletime. In effect, code calling these functions should run with
+the same performance as code using the infix operators directly.
+
+=head2 is_strequ
+
+   my $equal = is_strequ( $lhs, $rhs );
+
+A function version of the L</equ> stringy operator.
+
+=head2 is_numequ
+
+   my $equal = is_numequ( $lhs, $rgh );
+
+A function version of the L</===> numerical operator.
+
+=cut
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
